@@ -7,7 +7,7 @@ import numpy as np
 
 
 from .abc import Codec
-from .compat import buffer_copy, handle_datetime
+from .compat import buffer_copy, handle_datetime, buffer_tobytes, PY2
 
 
 class Zlib(Codec):
@@ -30,9 +30,19 @@ class Zlib(Codec):
         # deal with lack of buffer support for datetime64 and timedelta64
         buf = handle_datetime(buf)
 
-        # if numpy array, can only handle C contiguous directly
-        if isinstance(buf, np.ndarray) and not buf.flags.c_contiguous:
-            buf = buf.tobytes(order='A')
+        if isinstance(buf, np.ndarray):
+
+            # cannot compress object array
+            if buf.dtype == object:
+                raise ValueError('cannot encode object array')
+
+            # if numpy array, can only handle C contiguous directly
+            if not buf.flags.c_contiguous:
+                buf = buf.tobytes(order='A')
+
+        if PY2:  # pragma: py3 no cover
+            # ensure bytes, PY2 cannot handle things like bytearray
+            buf = buffer_tobytes(buf)
 
         # do compression
         return _zlib.compress(buf, self.level)
@@ -40,6 +50,10 @@ class Zlib(Codec):
     # noinspection PyMethodMayBeStatic
     def decode(self, buf, out=None):
 
+        if PY2:  # pragma: py3 no cover
+            # ensure bytes, PY2 cannot handle things like bytearray
+            buf = buffer_tobytes(buf)
+
         # do decompression
         dec = _zlib.decompress(buf)
 
